@@ -24,7 +24,7 @@ project = "Translate Toolkit"
 copyright = "2002-2022, Translate"
 
 # The short X.Y version.
-version = "3.5.3"
+version = "3.6.1"
 
 # The full version, including alpha/beta/rc tags
 release = version
@@ -194,12 +194,15 @@ coverage_write_headline = False
 # -- Options for intersphinx extension ---------------------------------------
 
 intersphinx_mapping = {
-    "python": ("https://docs.python.org/3.9", None),
+    "python": ("https://docs.python.org/3/", None),
     "pytest": ("https://docs.pytest.org/en/latest/", None),
-    "django": ("http://django.readthedocs.org/en/latest/", None),
-    "pootle": ("http://docs.translatehouse.org/projects/pootle/en/latest/", None),
+    "django": (
+        "https://docs.djangoproject.com/en/stable/",
+        "https://docs.djangoproject.com/en/stable/_objects/",
+    ),
+    "pootle": ("https://docs.translatehouse.org/projects/pootle/en/latest/", None),
     "guide": (
-        "http://docs.translatehouse.org/projects/localization-guide/en/latest/",
+        "https://docs.translatehouse.org/projects/localization-guide/en/latest/",
         None,
     ),
 }
@@ -210,9 +213,8 @@ intersphinx_mapping = {
 extlinks = {
     # :role: (URL, prefix)
     "issue": ("https://github.com/translate/translate/issues/%s", "issue "),
-    "man": ("http://linux.die.net/man/1/%s", ""),
-    "wiki": ("http://translate.sourceforge.net/wiki/%s", ""),
-    "wp": ("http://en.wikipedia.org/wiki/%s", ""),
+    "man": ("https://linux.die.net/man/1/%s", ""),
+    "wp": ("https://en.wikipedia.org/wiki/%s", ""),
 }
 
 # -- Options for Linkcheck -------------------------------------------------
